

# List of Snips icons

|Icon | Name|
|-------------------------------------------------------------------------------------------------------------------------|-----------------|
|![https://console.snips.ai/images/bundles/default-bundle.svg](https://console.snips.ai/images/bundles/default-bundle.svg)|default-bundle|
|![https://console.snips.ai/images/bundles/bundle-air.svg](https://console.snips.ai/images/bundles/bundle-air.svg)|bundle-air|
|![https://console.snips.ai/images/bundles/bundle-assistant.svg](https://console.snips.ai/images/bundles/bundle-assistant.svg)|bundle-assistant|
|![https://console.snips.ai/images/bundles/bundle-bank.svg](https://console.snips.ai/images/bundles/bundle-bank.svg)|bundle-bank|
|![https://console.snips.ai/images/bundles/bundle-battery.svg](https://console.snips.ai/images/bundles/bundle-battery.svg)|bundle-battery|
|![https://console.snips.ai/images/bundles/bundle-bluetooth.svg](https://console.snips.ai/images/bundles/bundle-bluetooth.svg)|bundle-bluetooth|
|![https://console.snips.ai/images/bundles/bundle-box.svg](https://console.snips.ai/images/bundles/bundle-box.svg)|bundle-box|
|![https://console.snips.ai/images/bundles/bundle-calculator.svg](https://console.snips.ai/images/bundles/bundle-calculator.svg)|bundle-calculator|
|![https://console.snips.ai/images/bundles/bundle-calendar.svg](https://console.snips.ai/images/bundles/bundle-calendar.svg)|bundle-calendar|
|![https://console.snips.ai/images/bundles/bundle-camera.svg](https://console.snips.ai/images/bundles/bundle-camera.svg)|bundle-camera|
|![https://console.snips.ai/images/bundles/bundle-car.svg](https://console.snips.ai/images/bundles/bundle-car.svg)|bundle-car|
|![https://console.snips.ai/images/bundles/bundle-coffee.svg](https://console.snips.ai/images/bundles/bundle-coffee.svg)|bundle-coffee|
|![https://console.snips.ai/images/bundles/bundle-direction.svg](https://console.snips.ai/images/bundles/bundle-direction.svg)|bundle-direction|
|![https://console.snips.ai/images/bundles/bundle-drink.svg](https://console.snips.ai/images/bundles/bundle-drink.svg)|bundle-drink|
|![https://console.snips.ai/images/bundles/bundle-film.svg](https://console.snips.ai/images/bundles/bundle-film.svg)|bundle-film|
|![https://console.snips.ai/images/bundles/bundle-folder.svg](https://console.snips.ai/images/bundles/bundle-folder.svg)|bundle-folder|
|![https://console.snips.ai/images/bundles/bundle-games.svg](https://console.snips.ai/images/bundles/bundle-games.svg)|bundle-games|
|![https://console.snips.ai/images/bundles/bundle-headphones.svg](https://console.snips.ai/images/bundles/bundle-headphones.svg)|bundle-headphones|
|![https://console.snips.ai/images/bundles/bundle-home.svg](https://console.snips.ai/images/bundles/bundle-home.svg)|bundle-home|
|![https://console.snips.ai/images/bundles/bundle-key.svg](https://console.snips.ai/images/bundles/bundle-key.svg)|bundle-key|
|![https://console.snips.ai/images/bundles/bundle-lamp.svg](https://console.snips.ai/images/bundles/bundle-lamp.svg)|bundle-lamp|
|![https://console.snips.ai/images/bundles/bundle-lights.svg](https://console.snips.ai/images/bundles/bundle-lights.svg)|bundle-lights|
|![https://console.snips.ai/images/bundles/bundle-location.svg](https://console.snips.ai/images/bundles/bundle-location.svg)|bundle-location|
|![https://console.snips.ai/images/bundles/bundle-lock.svg](https://console.snips.ai/images/bundles/bundle-lock.svg)|bundle-lock|
|![https://console.snips.ai/images/bundles/bundle-map.svg](https://console.snips.ai/images/bundles/bundle-map.svg)|bundle-map|
|![https://console.snips.ai/images/bundles/bundle-medicine.svg](https://console.snips.ai/images/bundles/bundle-medicine.svg)|bundle-medicine|
|![https://console.snips.ai/images/bundles/bundle-microphone.svg](https://console.snips.ai/images/bundles/bundle-microphone.svg)|bundle-microphone|
|![https://console.snips.ai/images/bundles/bundle-monitor.svg](https://console.snips.ai/images/bundles/bundle-monitor.svg)|bundle-monitor|
|![https://console.snips.ai/images/bundles/bundle-movie.svg](https://console.snips.ai/images/bundles/bundle-movie.svg)|bundle-movie|
|![https://console.snips.ai/images/bundles/bundle-music.svg](https://console.snips.ai/images/bundles/bundle-music.svg)|bundle-music|
|![https://console.snips.ai/images/bundles/bundle-plant.svg](https://console.snips.ai/images/bundles/bundle-plant.svg)|bundle-plant|
|![https://console.snips.ai/images/bundles/bundle-radio.svg](https://console.snips.ai/images/bundles/bundle-radio.svg)|bundle-radio|
|![https://console.snips.ai/images/bundles/bundle-rain.svg](https://console.snips.ai/images/bundles/bundle-rain.svg)|bundle-rain|
|![https://console.snips.ai/images/bundles/bundle-recording.svg](https://console.snips.ai/images/bundles/bundle-recording.svg)|bundle-recording|
|![https://console.snips.ai/images/bundles/bundle-restart.svg](https://console.snips.ai/images/bundles/bundle-restart.svg)|bundle-restart|
|![https://console.snips.ai/images/bundles/bundle-security.svg](https://console.snips.ai/images/bundles/bundle-security.svg)|bundle-security|
|![https://console.snips.ai/images/bundles/bundle-settings.svg](https://console.snips.ai/images/bundles/bundle-settings.svg)|bundle-settings|
|![https://console.snips.ai/images/bundles/bundle-shutdown.svg](https://console.snips.ai/images/bundles/bundle-shutdown.svg)|bundle-shutdown|
|![https://console.snips.ai/images/bundles/bundle-sport.svg](https://console.snips.ai/images/bundles/bundle-sport.svg)|bundle-sport|
|![https://console.snips.ai/images/bundles/bundle-spotify.svg](https://console.snips.ai/images/bundles/bundle-spotify.svg)|bundle-spotify|
|![https://console.snips.ai/images/bundles/bundle-star.svg](https://console.snips.ai/images/bundles/bundle-star.svg)|bundle-star|
|![https://console.snips.ai/images/bundles/bundle-store.svg](https://console.snips.ai/images/bundles/bundle-store.svg)|bundle-store|
|![https://console.snips.ai/images/bundles/bundle-sun.svg](https://console.snips.ai/images/bundles/bundle-sun.svg)|bundle-sun|
|![https://console.snips.ai/images/bundles/bundle-temperature.svg](https://console.snips.ai/images/bundles/bundle-temperature.svg)|bundle-temperature|
|![https://console.snips.ai/images/bundles/bundle-time.svg](https://console.snips.ai/images/bundles/bundle-time.svg)|bundle-time|
|![https://console.snips.ai/images/bundles/bundle-timer.svg](https://console.snips.ai/images/bundles/bundle-timer.svg)|bundle-timer|
|![https://console.snips.ai/images/bundles/bundle-transport.svg](https://console.snips.ai/images/bundles/bundle-transport.svg)|bundle-transport|
|![https://console.snips.ai/images/bundles/bundle-vynil.svg](https://console.snips.ai/images/bundles/bundle-vynil.svg)|bundle-vynil|
|![https://console.snips.ai/images/bundles/bundle-wallet.svg](https://console.snips.ai/images/bundles/bundle-wallet.svg)|bundle-wallet|
|![https://console.snips.ai/images/bundles/bundle-weather.svg](https://console.snips.ai/images/bundles/bundle-weather.svg)|bundle-weather|
|![https://console.snips.ai/images/bundles/bundle-wind.svg](https://console.snips.ai/images/bundles/bundle-wind.svg)|bundle-wind|
|![https://console.snips.ai/images/bundles/bundle-yoga.svg](https://console.snips.ai/images/bundles/bundle-yoga.svg)|bundle-yoga|

